pub struct Menu<'a, 'b, T, Message, Theme = Theme>where
'b: 'a,
Theme: Catalog,{ /* private fields */ }Expand description
A list of selectable options.
Implementations
Sourceimpl<'a, 'b, T, Message, Theme> Menu<'a, 'b, T, Message, Theme>
impl<'a, 'b, T, Message, Theme> Menu<'a, 'b, T, Message, Theme>
Sourcepub fn new(
state: &'a mut State,
options: &'a [T],
hovered_option: &'a mut Option<usize>,
to_string: &'a dyn Fn(&T) -> String,
on_selected: impl FnMut(T) -> Message + 'a,
on_option_hovered: Option<&'a dyn Fn(T) -> Message>,
class: &'a <Theme as Catalog>::Class<'b>,
) -> Menu<'a, 'b, T, Message, Theme>
pub fn new( state: &'a mut State, options: &'a [T], hovered_option: &'a mut Option<usize>, to_string: &'a dyn Fn(&T) -> String, on_selected: impl FnMut(T) -> Message + 'a, on_option_hovered: Option<&'a dyn Fn(T) -> Message>, class: &'a <Theme as Catalog>::Class<'b>, ) -> Menu<'a, 'b, T, Message, Theme>
Sourcepub fn height(
self,
height: impl Into<Length>,
) -> Menu<'a, 'b, T, Message, Theme>
pub fn height( self, height: impl Into<Length>, ) -> Menu<'a, 'b, T, Message, Theme>
Sets the height of the Menu.
Sourcepub fn text_size(
self,
text_size: impl Into<Pixels>,
) -> Menu<'a, 'b, T, Message, Theme>
pub fn text_size( self, text_size: impl Into<Pixels>, ) -> Menu<'a, 'b, T, Message, Theme>
Sets the text size of the Menu.
Sourcepub fn line_height(
self,
line_height: impl Into<LineHeight>,
) -> Menu<'a, 'b, T, Message, Theme>
pub fn line_height( self, line_height: impl Into<LineHeight>, ) -> Menu<'a, 'b, T, Message, Theme>
Sets the text text::LineHeight of the Menu.
Sourcepub fn shaping(self, shaping: Shaping) -> Menu<'a, 'b, T, Message, Theme>
pub fn shaping(self, shaping: Shaping) -> Menu<'a, 'b, T, Message, Theme>
Sets the text::Shaping strategy of the Menu.
Sourcepub fn ellipsis(self, ellipsis: Ellipsis) -> Menu<'a, 'b, T, Message, Theme>
pub fn ellipsis(self, ellipsis: Ellipsis) -> Menu<'a, 'b, T, Message, Theme>
Sets the text::Ellipsis strategy of the Menu.
Sourcepub fn font(self, font: impl Into<Font>) -> Menu<'a, 'b, T, Message, Theme>
pub fn font(self, font: impl Into<Font>) -> Menu<'a, 'b, T, Message, Theme>
Sets the font of the Menu.
Sourcepub fn overlay<Renderer>(
self,
renderer: &Renderer,
position: Point,
window: Size,
target_height: f32,
) -> Element<'a, Message, Theme, Renderer>where
Renderer: Renderer + 'a,
pub fn overlay<Renderer>(
self,
renderer: &Renderer,
position: Point,
window: Size,
target_height: f32,
) -> Element<'a, Message, Theme, Renderer>where
Renderer: Renderer + 'a,
Turns the Menu into an overlay::Element at the given target
position.
position is the target’s position in screen coordinates, and
window is the size of the window.
The target_height will be used to display the menu either on top
of the target or under it, depending on the screen position and the
dimensions of the Menu.